AnimatedPlayButton class

Inheritance

Constructors

AnimatedPlayButton({Key? key, required VoidCallback onPressed, bool initialIsPlaying = false, IconData? playIcon, IconData? pauseIcon, Color? buttonBackgroundColor, double? height, double? width, Color? playIconColor, Color? pauseIconColor, double? playIconSize, double? pauseIconSize, Function? onPause})
const

Properties

buttonBackgroundColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
initialIsPlaying bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPause Function?
final
onPressed VoidCallback
final
pauseIcon IconData?
final
pauseIconColor Color?
final
pauseIconSize double?
final
playIcon IconData?
final
playIconColor Color?
final
playIconSize double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _AnimatedPlayButton
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited